# Dash Bio Utils

Dash Bio utils is a set of helper scripts that work together with the
[`dash-bio`](https://github.com/plotly/dash-bio) package to make it
easier to use files that are directly downloaded from databases.